# Time Resource Provider

The Time Resource Provider lets you manage [time](https://www.pulumi.com/registry/packages/time/) resources.

## Installing

This package is available for several languages/platforms:

### Node.js (JavaScript/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

```bash
npm install @pulumiverse/time
```

or `yarn`:

```bash
yarn add @pulumiverse/time
```

### Python

To use from Python, install using `pip`:

```bash
pip install pulumiverse_time
```

### Go

To use from Go, use `go get` to grab the latest version of the library:

```bash
go get github.com/pulumiverse/pulumi-time/sdk/go/...
```

### .NET

To use from .NET, install using `dotnet add package`:

```bash
dotnet add package Pulumiverse.Time
```

## Configuration

The Time provider does not need any additional configuration.

## Reference

For detailed reference documentation, please visit [the Pulumi registry](https://www.pulumi.com/registry/packages/time/api-docs/).
